@@ -132,6 +132,16 @@ namespace rstpm2 {
 
   double Brent_fmin(double ax, double bx, double (*f)(double, void *),
 		    void *info, double tol);
+
+  double R_zeroin2(			/* An estimate of the root */
+    double ax,				/* Left border | of the range	*/
+    double bx,				/* Right border| the root is seeked*/
+    double fa, double fb,		/* f(a), f(b) */
+    double (*f)(double x, void *info),	/* Function under investigation	*/
+    void *info,				/* Add'l info passed on to f	*/
+    double *Tol,			/* Acceptable tolerance		*/
+    int *Maxit);				/* Max # of iterations */
+
   
   /** 
       Adapt a function object (functor) to work with Brent_fmin()
